@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gnome_vfs.cc,v 1.2 2003/12/22 17:12:01 murrayc Exp $ */
+/* $Id: generate_defs_gnome_vfs.cc,v 1.3 2004/03/02 09:58:06 murrayc Exp $ */
 
 /* generate_defs_gnomevfs.h
  *
@@ -23,12 +23,16 @@
 #include <libgnomevfs/gnome-vfs.h>
 //#include <libgnomevfs/gnome-vfs-metadata.h>
 #include <libgnomevfs/gnome-vfs-mime-monitor.h>
+#include <libgnomevfs/gnome-vfs-volume-monitor.h>
 
 int main (int argc, char *argv[])
 {
     gnome_vfs_init();
     
     std::cout // <<  get_defs(GNOME_TYPE_VFS_METADATA)
-                 << get_defs(GNOME_VFS_MIME_MONITOR_TYPE);
+                 << get_defs(GNOME_VFS_MIME_MONITOR_TYPE)
+                 << get_defs(GNOME_VFS_TYPE_VOLUME_MONITOR)
+                 << get_defs(GNOME_VFS_TYPE_DRIVE)
+                 << get_defs(GNOME_VFS_TYPE_VOLUME);
     return 0;
 }
